pyorbs
======
A tool for managing Python virtual environments.

Getting Started
---------------
Please visit the `project documentation <https://pyorbs.readthedocs.io>`_ to learn more about
working with pyorbs.

Contributing
------------
Before you start contributing to this project, please make sure you have read the entire
"Development" section of the project documentation.
